@@ -5,6 +5,7 @@
 
 export MALLOC_CHECK_=3
 export MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
+export LC_ALL=C
 
 echo "TESTING: AppImage v1 (test/appimage/appimage-v1.exp)"
 ./appimage-v1.exp
@@ -17,3 +18,6 @@ echo "TESTING: AppImage file name (test/appimage/filename.exp)";
 
 echo "TESTING: AppImage argsv1 (test/appimage/appimage-args.exp)"
 ./appimage-args.exp
+
+echo "TESTING: AppImage trace (test/appimage/appimage-trace.exp)"
+./appimage-args.exp
